@@ -144,7 +144,17 @@ class Labelling:
         return self.run(command, **kwargs)
 
     def cval(
-        self, wn="", v1="", v2="", v3="", v4="", v5="", v6="", v7="", v8="", **kwargs
+        self,
+        wn="",
+        v1="",
+        v2="",
+        v3="",
+        v4="",
+        v5="",
+        v6="",
+        v7="",
+        v8="",
+        **kwargs,
     ):
         """Specifies nonuniform contour values on stress displays.
 
