@@ -2,6 +2,7 @@
 session, including the jobname, Graphical User Interface behavior, and
 file switching.
 """
+from ansys.mapdl.core.errors import MapdlRuntimeError
 
 
 class RunControls:
@@ -143,7 +144,7 @@ class RunControls:
         """
         dirpath = str(dirpath)
         if not (dirpath.startswith("'") and dirpath.endswith("'")) and "'" in dirpath:
-            raise RuntimeError(
+            raise MapdlRuntimeError(
                 'The CWD command does not accept paths that contain singular quotes "'
             )
         return self.run(f"/CWD,'{dirpath}'", **kwargs)
