@@ -19,6 +19,7 @@ import numpy as np
 
 from ansys.mapdl import core as pymapdl
 from ansys.mapdl.core import _HAS_PYVISTA, LINUX_DEFAULT_DIRS, LOG
+from ansys.mapdl.core.errors import MapdlExitedError
 
 try:
     import ansys.tools.report as pyansys_report
@@ -93,7 +94,6 @@ def get_linux_default_ansys_bin(rver):
     """
     for each_path in LINUX_DEFAULT_DIRS:
         for each_file in [f"ansys{rver}", "mapdl"]:
-
             ans_root = os.getenv(f"AWP_ROOT{rver}", each_path)
             mapdlbin = os.path.join(ans_root, f"v{rver}", "ansys", "bin", each_file)
 
@@ -529,7 +529,7 @@ def create_temp_dir(tmpdir=None):
     try:
         os.mkdir(path)
     except:
-        raise RuntimeError(
+        raise MapdlRuntimeError(
             "Unable to create temporary working "
             "directory %s\n" % path + "Please specify run_location="
         )
@@ -760,12 +760,12 @@ class Information:
         that change over the MAPDL session."""
         try:
             if self._mapdl._exited:  # pragma: no cover
-                raise RuntimeError("Information class: MAPDL exited")
+                raise MapdlExitedError("Information class: MAPDL exited")
 
             stats = self._mapdl.slashstatus("ALL")
         except Exception:  # pragma: no cover
             self._stats = None
-            raise RuntimeError("Information class: MAPDL exited")
+            raise MapdlExitedError("Information class: MAPDL exited")
 
         stats = stats.replace("\n ", "\n")  # Bit of formatting
         self._stats = stats
@@ -1132,7 +1132,6 @@ def requires_package(package_name, softerror=False):
     def decorator(function):
         @wraps(function)
         def wrapper(self, *args, **kwargs):
-
             try:
                 importlib.import_module(package_name)
                 return function(self, *args, **kwargs)
@@ -1240,7 +1239,6 @@ def wrap_point_SEL(entity="node"):
             )
 
             if isinstance(vmin, (set, tuple, list, np.ndarray)):
-
                 if kwargs.get("Used_P", False) and (
                     (isinstance(vmin, np.ndarray) and vmin.size != 0) or len(vmin) == 0
                 ):
