@@ -30,7 +30,7 @@ def available_ports(n_ports, starting_port=MAPDL_DEFAULT_PORT):
         port += 1
 
     if len(ports) < n_ports:
-        raise RuntimeError(
+        raise MapdlRuntimeError(
             f"There are not {n_ports} available ports between {starting_port} and 65536"
         )
 
@@ -197,7 +197,7 @@ class LocalMapdlPool:
 
     def _verify_unique_ports(self):
         if len(self._ports) != len(self):
-            raise RuntimeError("MAPDLPool has overlapping ports")
+            raise MapdlRuntimeError("MAPDLPool has overlapping ports")
 
     def map(
         self,
@@ -280,7 +280,7 @@ class LocalMapdlPool:
         if not len(self):
             # instances could still be spawning...
             if not all(v is None for v in self._instances):
-                raise RuntimeError("No MAPDL instances available.")
+                raise MapdlRuntimeError("No MAPDL instances available.")
 
         results = []
 
